@@ -33,7 +33,6 @@ mod hooks;
 mod ignore_me;
 mod include_exclude;
 mod interactive;
-mod log;
 mod progressbar;
 mod project_variables;
 mod template;
@@ -49,21 +48,24 @@ pub use args::*;
 use anyhow::{anyhow, bail, Context, Result};
 use config::{locate_template_configs, Config, CONFIG_FILE_NAME};
 use console::style;
+use env_logger::fmt::Formatter;
 use hooks::execute_hooks;
 use ignore_me::remove_dir_files;
 use interactive::prompt_and_check_variable;
+use log::Record;
+use log::{info, warn};
 use project_variables::{StringEntry, TemplateSlots, VarInfo};
 use std::{
     borrow::Borrow,
     cell::RefCell,
     collections::HashMap,
     env, fs,
+    io::Write,
     path::{Path, PathBuf},
     sync::{Arc, Mutex},
 };
-use user_parsed_input::{TemplateLocation, UserParsedInput};
-
 use tempfile::TempDir;
+use user_parsed_input::{TemplateLocation, UserParsedInput};
 
 use crate::template_variables::{
     load_env_and_args_template_values, CrateName, ProjectDir, ProjectNameInput,
@@ -75,6 +77,20 @@ use self::git::try_get_branch_from_path;
 use self::hooks::evaluate_script;
 use self::template::{create_liquid_object, set_project_name_variables, LiquidObjectResource};
 
+/// Logging formatter function
+pub fn log_formatter(
+    buf: &mut Formatter,
+    record: &Record,
+) -> std::result::Result<(), std::io::Error> {
+    let prefix = match record.level() {
+        log::Level::Error => format!("{} ", emoji::ERROR),
+        log::Level::Warn => format!("{} ", emoji::WARN),
+        _ => "".to_string(),
+    };
+
+    writeln!(buf, "{}{}", prefix, record.args())
+}
+
 /// # Panics
 pub fn generate(args: GenerateArgs) -> Result<PathBuf> {
     let _working_dir_scope = ScopedWorkingDirectory::default();
@@ -103,9 +119,8 @@ pub fn generate(args: GenerateArgs) -> Result<PathBuf> {
         .unwrap_or(false)
         && !user_parsed_input.init
     {
-        eprintln!(
-            "{} {}",
-            emoji::WARN,
+        warn!(
+            "{}",
             style("Template specifies --init, while not specified on the command line. Output location is affected!").bold().red(),
         );
 
@@ -136,7 +151,7 @@ fn copy_expanded_template(
     config: Config,
     branch: Option<&str>,
 ) -> Result<PathBuf> {
-    println!(
+    info!(
         "{} {} `{}`{}",
         emoji::WRENCH,
         style("Moving generated files into:").bold(),
@@ -152,7 +167,7 @@ fn copy_expanded_template(
         info!("{}", style("Initializing a fresh Git repository").bold());
         vcs.initialize(&project_dir, branch, user_parsed_input.force_git_init())?;
     }
-    println!(
+    info!(
         "{} {} {} {}",
         emoji::SPARKLE,
         style("Done!").bold().green(),
@@ -163,7 +178,7 @@ fn copy_expanded_template(
 }
 
 fn test_expanded_template(template_dir: &PathBuf, args: Option<Vec<String>>) -> Result<PathBuf> {
-    println!(
+    info!(
         "{} {}{}{}",
         emoji::WRENCH,
         style("Running \"").bold(),
@@ -205,8 +220,18 @@ fn get_source_template_into_temp(
 ) -> Result<(TempDir, Option<String>)> {
     match template_location {
         TemplateLocation::Git(git) => {
-            git::clone_git_template_into_temp(git.url(), git.branch(), git.tag(), git.identity())
-                .map(|(dir, branch)| (dir, Some(branch)))
+            let result = git::clone_git_template_into_temp(
+                git.url(),
+                git.branch(),
+                git.tag(),
+                git.identity(),
+            )
+            .map(|(dir, branch)| (dir, Some(branch)));
+            if let Ok((ref temp_dir, _)) = result {
+                git::remove_history(temp_dir.path())?;
+                strip_liquid_suffixes(temp_dir.path())?;
+            };
+            result
         }
         TemplateLocation::Path(path) => {
             let temp_dir = tempfile::tempdir()?;
@@ -217,6 +242,24 @@ fn get_source_template_into_temp(
     }
 }
 
+/// remove .liquid suffixes from git templates for parity with path templates
+fn strip_liquid_suffixes(dir: impl AsRef<Path>) -> Result<()> {
+    for entry in fs::read_dir(dir)? {
+        let entry = entry?;
+        let entry_type = entry.file_type()?;
+
+        if entry_type.is_dir() {
+            strip_liquid_suffixes(entry.path())?;
+        } else if entry_type.is_file() {
+            let path = entry.path().to_string_lossy().to_string();
+            if let Some(new_path) = path.clone().strip_suffix(".liquid") {
+                fs::rename(path, new_path)?;
+            }
+        }
+    }
+    Ok(())
+}
+
 /// resolve the template location for the actual template to expand
 fn resolve_template_dir(template_base_dir: &TempDir, subfolder: Option<&str>) -> Result<PathBuf> {
     let template_dir = resolve_template_dir_subfolder(template_base_dir.path(), subfolder)?;
@@ -381,9 +424,8 @@ pub(crate) fn copy_dir_all(
                         )
                     }
                     (true, true) => {
-                        eprintln!(
-                            "{} {} {}",
-                            emoji::WARN,
+                        warn!(
+                            "{} {}",
                             style("Overwriting file:").bold().red(),
                             style(dst_path.display()).bold().red(),
                         );
@@ -436,7 +478,7 @@ fn locate_template_file(
     let template_base_folder = template_base_folder.as_ref();
     let mut search_folder = template_folder.as_ref().to_path_buf();
     loop {
-        let file_path = search_folder.join(name.borrow());
+        let file_path = search_folder.join::<&str>(name.borrow());
         if file_path.exists() {
             return Ok(file_path);
         }
@@ -477,19 +519,19 @@ fn expand_template(
     let crate_name = CrateName::from(&project_name_input);
     set_project_name_variables(&liquid_object, &destination, &project_name, &crate_name)?;
 
-    println!(
+    info!(
         "{} {} {}",
         emoji::WRENCH,
         style(format!("Destination: {destination}")).bold(),
         style("...").bold()
     );
-    println!(
+    info!(
         "{} {} {}",
         emoji::WRENCH,
         style(format!("project-name: {project_name}")).bold(),
         style("...").bold()
     );
-    println!(
+    info!(
         "{} {} {}",
         emoji::WRENCH,
         style("Generating template").bold(),
@@ -537,6 +579,7 @@ fn expand_template(
         rhai_engine,
         &rhai_filter_files,
         &mut pbar,
+        args.verbose,
     )?;
 
     // run post-hooks
