@@ -10,13 +10,13 @@ use heck::{
 use liquid::model;
 use liquid_core::{parser::FilterArguments, Filter, ParseFilter, Runtime, Value, ValueView};
 use liquid_derive::FilterReflection;
+use log::warn;
 use std::{
     path::PathBuf,
     sync::{Arc, Mutex},
 };
 
 use crate::{
-    emoji,
     hooks::{create_rhai_engine, PoisonError},
     template::LiquidObjectResource,
 };
@@ -152,9 +152,8 @@ impl Filter for RhaiFilter {
         );
         let file_path = PathBuf::from(input.to_kstr().to_string());
         if !file_path.exists() {
-            eprintln!(
-                "{} {} {} {}",
-                emoji::WARN,
+            warn!(
+                "{} {} {}",
                 style("Filter script").bold().yellow(),
                 style(file_path.display()).bold().red(),
                 style("not found").bold().yellow(),
@@ -173,9 +172,8 @@ impl Filter for RhaiFilter {
         match result {
             Ok(r) => Ok(Value::Scalar(model::Scalar::from(r))),
             Err(err) => {
-                eprintln!(
-                    "{} {} {} {} {}",
-                    emoji::WARN,
+                warn!(
+                    "{} {} {} {}",
                     style("Filter script").bold().yellow(),
                     style(file_path.display()).bold().red(),
                     style("contained error").bold().yellow(),
